@@ -48,16 +48,9 @@ class PVProduction:
         self.irr_data = irr_data
 
         if not isinstance(self.load.index, pd.DatetimeIndex) or not isinstance(self.load.index, pd.DatetimeIndex):
-
             try:
                 self.load.index = pd.to_datetime(self.load.index)
                 self.irr_data.index = pd.to_datetime(self.irr_data.index)
-
-                print(self.irr_data.index.hour)
-
-                # if not self.load.index.hour or not self.irr_data.index.hour:
-                #     raise ValueError('Los datos deben ser horarios')
-
             except:
                 raise TypeError('Index must be pd.DateTimeIndex')
             
